RewardedInterstitialAd class
A rewarded interstitial ad with an interstitial-style full-screen flow.
Properties
- adId → String
-
final
- adUnitId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener ↔ RewardedInterstitialAdListener?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required void onUserEarnedReward(RewardItem reward)}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
{required String adUnitId, AdRequest? request}) → Future< RewardedInterstitialAd> -
Load a single rewarded interstitial ad. Use AdMob's sample unit ID
ca-app-pub-3940256099942544/5354046379for testing.